package MyB;
use 5.010;
use strict;
use warnings;

use MyC;

sub run { say 'MyB' }

1;

